@@ -31,13 +31,15 @@ use lib './lib';
 use WWW::Search::Scraper(qw(1.48));
 use WWW::Search::Scraper::Request;
 use vars qw($VERSION);
+use diagnostics;
+
 $VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
 
     select STDERR; $| = 1; select STDOUT; $| = 1; 
 
     my ($engine, $query, $debug, $options) = @ARGV;
     $engine = 'eBay'  unless $engine;
-    $query =~ s/(['"])(.*)\1$/\2/;
+    $query =~ s/(['"])(.*)\1$/$2/;
     $debug = 'U'      unless $debug;
 
     my $scraper = new WWW::Search::Scraper( $engine );
